@@ -152,9 +152,18 @@ def global_arg(*args, **kwargs):
     return args, kwargs
 
 
-def say(*args):
-    for s in args:
-        print ">> %s" % s
+class say:
+    INDENTATION = 0
+
+    def __init__(self, *args):
+        for s in args:
+            print ('  ' * say.INDENTATION) + s
+
+    def __enter__(self):
+        say.INDENTATION += 1
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        say.INDENTATION -= 1
 
 
 def _get_parser(f):
